@@ -30,7 +30,7 @@ use Evented::Object::EventFire;
 use Evented::Object::Collection;
 
 # always use 2 decimals. change other packages too.
-our $VERSION = '5.59';
+our $VERSION = '5.62';
 
 # creates a new evented object.
 sub new {
@@ -230,7 +230,8 @@ sub prepare_event {
 # returns the collection.
 #
 sub prepare_together {
-    my ($obj, %collection);
+    my $obj;
+    my $collection = Evented::Object::Collection->new;
     foreach my $set (@_) {
         my $eo;
 
@@ -260,12 +261,13 @@ sub prepare_together {
         }
 
         # add to the collection.
-        my %mini_collection = %{ _get_callbacks($eo, $event_name, @args) };
-        @collection{ keys %mini_collection } = values %mini_collection;
+        my ($callbacks, $names) =
+            _get_callbacks($eo, $event_name, @args);
+        $collection->push_callbacks($callbacks, $names);
 
     }
 
-    return bless { pending => \%collection }, 'Evented::Object::Collection';
+    return $collection;
 }
 
 #####################
@@ -443,7 +445,7 @@ sub _get_callback_named {
 # internal use only.
 sub _get_callbacks {
     my ($eo, $event_name, @args) = @_;
-    my %collection;
+    my (%callbacks, %callback_names);
 
     # start out with two stores: the object and the package.
     my @stores = (
@@ -485,17 +487,21 @@ sub _get_callbacks {
         foreach my $priority (keys %$store) {
 
             # create a group reference.
-            my $group = [ $eo, $event_name, \@args];
+            my $group_id = "$eo/$event_name";
+            my $group    = [ $eo, $event_name, \@args, $group_id ];
             weaken($group->[0]);
 
-            # add each callback.
-            $collection{ $_->{name} } = [ $priority, $group, $_ ]
-                foreach @{ $store->{$priority} };
+            # add each callback set. inject callback name.
+            foreach my $cb (@{ $store->{$priority} }) {
+                $cb->{id} = "$group_id/$$cb{name}";
+                $callbacks{ $cb->{id} } = [ $priority, $group, $cb ];
+                $callback_names{$group_id}{ $cb->{name} } = $cb->{id};
+            }
 
         }
     }
 
-    return \%collection;
+    return wantarray ? (\%callbacks, \%callback_names) : \%callbacks;
 }
 
 # fire a class monitor event.
@@ -721,7 +727,7 @@ B<Fire objects and listeners>
 
 When an event is fired on an object, the same fire object is used for callbacks
 belonging to both the evented object and its listening objects. Therefore, callback names
-must be unique not only to the listener object but to the object being listened on as
+should be unique not only to the listener object but to the object being listened on as
 well.
 
 You should also note the values of the fire object:
@@ -899,7 +905,7 @@ enabled. This was added in Evented::Object 5.57.
 
  $eo->register_callback(myEvent => sub {
      ...
- }, name => 'some.callback', priority => 200);
+ }, 'some.callback, priority => 200);
 
 See the above method specification for parameters and supported options.
 
